tfplugin5 v5.10 — deprecated but still produced by older providers.
Generated by tonic-build from proto/tfplugin5.proto.
Modules
- apply_
resource_ change - Nested message and enum types in
ApplyResourceChange. - attribute_
path - Nested message and enum types in
AttributePath. - call_
function - Nested message and enum types in
CallFunction. - close_
ephemeral_ resource - Nested message and enum types in
CloseEphemeralResource. - configure
- Nested message and enum types in
Configure. - deferred
- Nested message and enum types in
Deferred. - diagnostic
- Nested message and enum types in
Diagnostic. - function
- Nested message and enum types in
Function. - generate_
resource_ config - Nested message and enum types in
GenerateResourceConfig. - get_
functions - Nested message and enum types in
GetFunctions. - get_
metadata - Nested message and enum types in
GetMetadata. - get_
provider_ schema - Nested message and enum types in
GetProviderSchema. - get_
provisioner_ schema - Nested message and enum types in
GetProvisionerSchema. - get_
resource_ identity_ schemas - Nested message and enum types in
GetResourceIdentitySchemas. - import_
resource_ state - Nested message and enum types in
ImportResourceState. - invoke_
action - Nested message and enum types in
InvokeAction. - list_
resource - Nested message and enum types in
ListResource. - move_
resource_ state - Nested message and enum types in
MoveResourceState. - open_
ephemeral_ resource - Nested message and enum types in
OpenEphemeralResource. - plan_
action - Nested message and enum types in
PlanAction. - plan_
resource_ change - Nested message and enum types in
PlanResourceChange. - prepare_
provider_ config - Nested message and enum types in
PrepareProviderConfig. - provider_
client - Generated client implementations.
- provider_
server - Generated server implementations.
- provision_
resource - Nested message and enum types in
ProvisionResource. - provisioner_
client - Generated client implementations.
- provisioner_
server - Generated server implementations.
- read_
data_ source - Nested message and enum types in
ReadDataSource. - read_
resource - Nested message and enum types in
ReadResource. - renew_
ephemeral_ resource - Nested message and enum types in
RenewEphemeralResource. - resource_
identity_ schema - Nested message and enum types in
ResourceIdentitySchema. - schema
- Nested message and enum types in
Schema. - stop
- Nested message and enum types in
Stop. - upgrade_
resource_ identity - Nested message and enum types in
UpgradeResourceIdentity. - upgrade_
resource_ state - Nested message and enum types in
UpgradeResourceState. - validate_
action_ config - Nested message and enum types in
ValidateActionConfig. - validate_
data_ source_ config - Nested message and enum types in
ValidateDataSourceConfig. - validate_
ephemeral_ resource_ config - Nested message and enum types in
ValidateEphemeralResourceConfig. - validate_
list_ resource_ config - Nested message and enum types in
ValidateListResourceConfig. - validate_
provisioner_ config - Nested message and enum types in
ValidateProvisionerConfig. - validate_
resource_ type_ config - Nested message and enum types in
ValidateResourceTypeConfig.
Structs
- Action
Schema - ActionSchema defines the schema for an action that can be invoked by Terraform.
- Apply
Resource Change - Attribute
Path - Call
Function - Client
Capabilities - ClientCapabilities allows Terraform to publish information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
- Close
Ephemeral Resource - Configure
- Deferred
- Deferred is a message that indicates that change is deferred for a reason.
- Diagnostic
- Dynamic
Value - DynamicValue is an opaque encoding of terraform data, with the field name indicating the encoding scheme used.
- Function
- Function
Error - Generate
Resource Config - GetFunctions
- GetMetadata
- GetProvider
Schema - GetProvisioner
Schema - GetResource
Identity Schemas - Import
Resource State - Invoke
Action - List
Resource - Move
Resource State - Open
Ephemeral Resource - Plan
Action - Plan
Resource Change - Prepare
Provider Config - Provision
Resource - RawState
- RawState holds the stored state for a resource to be upgraded by the provider. It can be in one of two formats, the current json encoded format in bytes, or the legacy flatmap format as a map of strings.
- Read
Data Source - Read
Resource - Renew
Ephemeral Resource - Resource
Identity Data - Resource
Identity Schema - ResourceIdentitySchema represents the structure and types of data used to identify a managed resource type. Effectively, resource identity is a versioned object that can be used to compare resources, whether already managed and/or being discovered.
- Schema
- Schema is the configuration schema for a Resource, Provider, or Provisioner.
- Server
Capabilities - ServerCapabilities allows providers to communicate extra information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
- Stop
- Upgrade
Resource Identity - Upgrade
Resource State - Validate
Action Config - Validate
Data Source Config - Validate
Ephemeral Resource Config - Validate
List Resource Config - Validate
Provisioner Config - Validate
Resource Type Config