pub enum Selector {
AttributeName(String),
ElementKeyString(String),
ElementKeyInt(i64),
}Variants
AttributeName(String)
Set “attribute_name” to represent looking up an attribute in the current object value.
ElementKeyString(String)
Set “element_key_*” to represent looking up an element in an indexable collection type.
ElementKeyInt(i64)
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn merge(
field: &mut Option<Selector>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Selector>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.