#[repr(i32)]pub enum Reason {
Unknown = 0,
ResourceConfigUnknown = 1,
ProviderConfigUnknown = 2,
AbsentPrereq = 3,
}Expand description
Reason is the reason for deferring the change.
Variants
Unknown = 0
UNKNOWN is the default value, and should not be used.
ResourceConfigUnknown = 1
RESOURCE_CONFIG_UNKNOWN is used when the config is partially unknown and the real values need to be known before the change can be planned.
ProviderConfigUnknown = 2
PROVIDER_CONFIG_UNKNOWN is used when parts of the provider configuration are unknown, e.g. the provider configuration is only known after the apply is done.
AbsentPrereq = 3
ABSENT_PREREQ is used when a hard dependency has not been satisfied.
Implementations
Sourceimpl Reason
impl Reason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.