pub struct Event {
pub identity: Option<ResourceIdentityData>,
pub display_name: String,
pub resource_object: Option<DynamicValue>,
pub diagnostic: Vec<Diagnostic>,
}Fields
identity: Option<ResourceIdentityData>identity is the resource identity data of the resource instance.
display_name: Stringdisplay_name can be displayed in a UI to make it easier for humans to identify a resource
resource_object: Option<DynamicValue>optional resource object which can be useful when combining list blocks in configuration
diagnostic: Vec<Diagnostic>A warning or error diagnostics for this event