pub struct Request {
pub type_name: String,
pub config: Option<DynamicValue>,
pub include_resource_object: bool,
pub limit: i64,
}Fields
type_name: Stringtype_name is the list resource type name.
config: Option<DynamicValue>configuration is the list ConfigSchema-based configuration data.
include_resource_object: boolwhen include_resource_object is set to true, the provider should include the full resource object for each result
limit: i64The maximum number of results that Terraform is expecting. The stream will stop, once this limit is reached.