Request

Struct Request 

pub struct Request {
    pub source_provider_address: String,
    pub source_type_name: String,
    pub source_schema_version: i64,
    pub source_state: Option<RawState>,
    pub target_type_name: String,
    pub source_private: Vec<u8>,
    pub source_identity: Option<RawState>,
    pub source_identity_schema_version: i64,
}

Fields

source_provider_address: String

The address of the provider the resource is being moved from.

source_type_name: String

The resource type that the resource is being moved from.

source_schema_version: i64

The schema version of the resource type that the resource is being moved from.

source_state: Option<RawState>

The raw state of the resource being moved. Only the json field is populated, as there should be no legacy providers using the flatmap format that support newly introduced RPCs.

target_type_name: String

The resource type that the resource is being moved to.

source_private: Vec<u8>

The private state of the resource being moved.

source_identity: Option<RawState>

The raw identity of the resource being moved. Only the json field is populated, as there should be no legacy providers using the flatmap format that support newly introduced RPCs.

source_identity_schema_version: i64

The identity schema version of the resource type that the resource is being moved from.