pub struct IdentityAttribute {
pub name: String,
pub type: Vec<u8>,
pub required_for_import: bool,
pub optional_for_import: bool,
pub description: String,
}Expand description
IdentityAttribute represents one value of data within resource identity. These are always used in resource identity comparisons.
Fields
name: Stringname is the identity attribute name
type: Vec<u8>type is the identity attribute type
required_for_import: boolrequired_for_import when enabled signifies that this attribute must be defined for ImportResourceState to complete successfully
optional_for_import: booloptional_for_import when enabled signifies that this attribute is not required for ImportResourceState, because it can be supplied by the provider. It is still possible to supply this attribute during import.
description: Stringdescription is a human-readable description of the attribute in Markdown