pub struct NestedBlock {
pub type_name: String,
pub block: Option<Block>,
pub nesting: i32,
pub min_items: i64,
pub max_items: i64,
}Fields
type_name: Stringblock: Option<Block>nesting: i32min_items: i64max_items: i64Implementations
Sourceimpl NestedBlock
impl NestedBlock
Sourcepub fn nesting(&self) -> NestingMode
pub fn nesting(&self) -> NestingMode
Returns the enum value of nesting, or the default if the field is set to an invalid enum value.
Sourcepub fn set_nesting(&mut self, value: NestingMode)
pub fn set_nesting(&mut self, value: NestingMode)
Sets nesting to the provided enum value.