pub struct ResourceIdentityData {
pub identity_data: Option<DynamicValue>,
}Fields
identity_data: Option<DynamicValue>identity_data is the resource identity data for the given definition. It should be decoded using the identity schema.
This data is considered permanent for the identity version and suitable for longer-term storage.