Module tfplugin6

Module tfplugin6 

tfplugin6 — current; required for sensitive-mark propagation, nested attribute types, optional-required-computed expression. Generated by tonic-build from proto/tfplugin6.proto.

Modules

apply_resource_change
Nested message and enum types in ApplyResourceChange.
attribute_path
Nested message and enum types in AttributePath.
call_function
Nested message and enum types in CallFunction.
close_ephemeral_resource
Nested message and enum types in CloseEphemeralResource.
configure_provider
Nested message and enum types in ConfigureProvider.
configure_state_store
Nested message and enum types in ConfigureStateStore.
deferred
Nested message and enum types in Deferred.
delete_state
Nested message and enum types in DeleteState.
diagnostic
Nested message and enum types in Diagnostic.
function
Nested message and enum types in Function.
generate_resource_config
Nested message and enum types in GenerateResourceConfig.
get_functions
Nested message and enum types in GetFunctions.
get_metadata
Nested message and enum types in GetMetadata.
get_provider_schema
Nested message and enum types in GetProviderSchema.
get_resource_identity_schemas
Nested message and enum types in GetResourceIdentitySchemas.
get_states
Nested message and enum types in GetStates.
import_resource_state
Nested message and enum types in ImportResourceState.
invoke_action
Nested message and enum types in InvokeAction.
list_resource
Nested message and enum types in ListResource.
lock_state
Nested message and enum types in LockState.
move_resource_state
Nested message and enum types in MoveResourceState.
open_ephemeral_resource
Nested message and enum types in OpenEphemeralResource.
plan_action
Nested message and enum types in PlanAction.
plan_resource_change
Nested message and enum types in PlanResourceChange.
provider_client
Generated client implementations.
provider_server
Generated server implementations.
read_data_source
Nested message and enum types in ReadDataSource.
read_resource
Nested message and enum types in ReadResource.
read_state_bytes
Nested message and enum types in ReadStateBytes.
renew_ephemeral_resource
Nested message and enum types in RenewEphemeralResource.
resource_identity_schema
Nested message and enum types in ResourceIdentitySchema.
schema
Nested message and enum types in Schema.
stop_provider
Nested message and enum types in StopProvider.
unlock_state
Nested message and enum types in UnlockState.
upgrade_resource_identity
Nested message and enum types in UpgradeResourceIdentity.
upgrade_resource_state
Nested message and enum types in UpgradeResourceState.
validate_action_config
Nested message and enum types in ValidateActionConfig.
validate_data_resource_config
Nested message and enum types in ValidateDataResourceConfig.
validate_ephemeral_resource_config
Nested message and enum types in ValidateEphemeralResourceConfig.
validate_list_resource_config
Nested message and enum types in ValidateListResourceConfig.
validate_provider_config
Nested message and enum types in ValidateProviderConfig.
validate_resource_config
Nested message and enum types in ValidateResourceConfig.
validate_state_store
Nested message and enum types in ValidateStateStore.
write_state_bytes
Nested message and enum types in WriteStateBytes.

Structs

ActionSchema
ActionSchema defines the schema for an action that can be invoked by Terraform.
ApplyResourceChange
AttributePath
CallFunction
ClientCapabilities
ClientCapabilities allows Terraform to publish information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
CloseEphemeralResource
ConfigureProvider
ConfigureStateStore
Deferred
Deferred is a message that indicates that change is deferred for a reason.
DeleteState
Diagnostic
DynamicValue
DynamicValue is an opaque encoding of terraform data, with the field name indicating the encoding scheme used.
Function
FunctionError
GenerateResourceConfig
GetFunctions
GetMetadata
GetProviderSchema
GetResourceIdentitySchemas
GetStates
ImportResourceState
InvokeAction
ListResource
LockState
MoveResourceState
OpenEphemeralResource
PlanAction
PlanResourceChange
RawState
RawState holds the stored state for a resource to be upgraded by the provider. It can be in one of two formats, the current json encoded format in bytes, or the legacy flatmap format as a map of strings.
ReadDataSource
ReadResource
ReadStateBytes
RenewEphemeralResource
RequestChunkMeta
ResourceIdentityData
ResourceIdentitySchema
ResourceIdentitySchema represents the structure and types of data used to identify a managed resource type. Effectively, resource identity is a versioned object that can be used to compare resources, whether already managed and/or being discovered.
Schema
Schema is the configuration schema for a Resource or Provider.
ServerCapabilities
ServerCapabilities allows providers to communicate extra information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
StateRange
StateStoreClientCapabilities
StateStoreServerCapabilities
StopProvider
UnlockState
UpgradeResourceIdentity
UpgradeResourceState
ValidateActionConfig
ValidateDataResourceConfig
ValidateEphemeralResourceConfig
ValidateListResourceConfig
ValidateProviderConfig
ValidateResourceConfig
ValidateStateStore
WriteStateBytes

Enums

StringKind