Parameter

Struct Parameter 

pub struct Parameter {
    pub name: String,
    pub type: Vec<u8>,
    pub allow_null_value: bool,
    pub allow_unknown_values: bool,
    pub description: String,
    pub description_kind: i32,
}

Fields

name: String

name is the human-readable display name for the parameter.

type: Vec<u8>

type is the type constraint for the parameter.

allow_null_value: bool

allow_null_value when enabled denotes that a null argument value can be passed to the provider. When disabled, Terraform returns an error if the argument value is null.

allow_unknown_values: bool

allow_unknown_values when enabled denotes that only wholly known argument values will be passed to the provider. When disabled, Terraform skips the function call entirely and assumes an unknown value result from the function.

description: String

description is human-readable documentation for the parameter.

description_kind: i32

description_kind is the formatting of the description.

Implementations

Source

impl Parameter

pub fn description_kind(&self) -> StringKind

Returns the enum value of description_kind, or the default if the field is set to an invalid enum value.

pub fn set_description_kind(&mut self, value: StringKind)

Sets description_kind to the provided enum value.