pub struct ClientCapabilities {
pub deferral_allowed: bool,
pub write_only_attributes_allowed: bool,
}Expand description
ClientCapabilities allows Terraform to publish information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
Fields
deferral_allowed: boolThe deferral_allowed capability signals that the client is able to handle deferred responses from the provider.
write_only_attributes_allowed: boolThe write_only_attributes_allowed capability signals that the client is able to handle write_only attributes for managed resources.