pub struct Function {
pub parameters: Vec<Parameter>,
pub variadic_parameter: Option<Parameter>,
pub return: Option<Return>,
pub summary: String,
pub description: String,
pub description_kind: i32,
pub deprecation_message: String,
}Fields
parameters: Vec<Parameter>parameters is the ordered list of positional function parameters.
variadic_parameter: Option<Parameter>variadic_parameter is an optional final parameter which accepts zero or more argument values, in which Terraform will send an ordered list of the parameter type.
return: Option<Return>Return is the function return parameter.
summary: Stringsummary is the human-readable shortened documentation for the function.
description: Stringdescription is human-readable documentation for the function.
description_kind: i32description_kind is the formatting of the description.
deprecation_message: Stringdeprecation_message is human-readable documentation if the function is deprecated.
Implementations
Sourceimpl Function
impl Function
Sourcepub fn description_kind(&self) -> StringKind
pub fn description_kind(&self) -> StringKind
Returns the enum value of description_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_description_kind(&mut self, value: StringKind)
pub fn set_description_kind(&mut self, value: StringKind)
Sets description_kind to the provided enum value.