pub struct ServerCapabilities {
pub plan_destroy: bool,
pub get_provider_schema_optional: bool,
pub move_resource_state: bool,
pub generate_resource_config: bool,
}Expand description
ServerCapabilities allows providers to communicate extra information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
Fields
plan_destroy: boolThe plan_destroy capability signals that a provider expects a call to PlanResourceChange when a resource is going to be destroyed.
get_provider_schema_optional: boolThe get_provider_schema_optional capability indicates that this provider does not require calling GetProviderSchema to operate normally, and the caller can used a cached copy of the provider’s schema.
move_resource_state: boolThe move_resource_state capability signals that a provider supports the MoveResourceState RPC.
generate_resource_config: boolThe generate_resource_config capability signals that a provider supports GenerateResourceConfig.