pub struct StateRange {
pub start: i64,
pub end: i64,
}Fields
start: i64start is the starting byte index for a chunk of state byte data. This index is in relation to the entire byte array that will be sent or received.
end: i64end is the ending byte index for a chunk of state byte data. This index is in relation to the entire byte array that will be sent or received.