pub struct Request {
pub type_name: String,
pub version: i64,
pub raw_state: Option<RawState>,
}Expand description
Request is the message that is sent to the provider during the UpgradeResourceState RPC.
This message intentionally does not include configuration data as any configuration-based or configuration-conditional changes should occur during the PlanResourceChange RPC. Additionally, the configuration is not guaranteed to exist (in the case of resource destruction), be wholly known, nor match the given prior state, which could lead to unexpected provider behaviors for practitioners.
Fields
type_name: Stringversion: i64version is the schema_version number recorded in the state file
raw_state: Option<RawState>raw_state is the raw states as stored for the resource. Core does not have access to the schema of prior_version, so it’s the provider’s responsibility to interpret this value using the appropriate older schema. The raw_state will be the json encoded state, or a legacy flat-mapped format.