Module tfplugin5

Module tfplugin5 

tfplugin5 v5.10 — deprecated but still produced by older providers. Generated by tonic-build from proto/tfplugin5.proto.

Modules

apply_resource_change
Nested message and enum types in ApplyResourceChange.
attribute_path
Nested message and enum types in AttributePath.
call_function
Nested message and enum types in CallFunction.
close_ephemeral_resource
Nested message and enum types in CloseEphemeralResource.
configure
Nested message and enum types in Configure.
deferred
Nested message and enum types in Deferred.
diagnostic
Nested message and enum types in Diagnostic.
function
Nested message and enum types in Function.
generate_resource_config
Nested message and enum types in GenerateResourceConfig.
get_functions
Nested message and enum types in GetFunctions.
get_metadata
Nested message and enum types in GetMetadata.
get_provider_schema
Nested message and enum types in GetProviderSchema.
get_provisioner_schema
Nested message and enum types in GetProvisionerSchema.
get_resource_identity_schemas
Nested message and enum types in GetResourceIdentitySchemas.
import_resource_state
Nested message and enum types in ImportResourceState.
invoke_action
Nested message and enum types in InvokeAction.
list_resource
Nested message and enum types in ListResource.
move_resource_state
Nested message and enum types in MoveResourceState.
open_ephemeral_resource
Nested message and enum types in OpenEphemeralResource.
plan_action
Nested message and enum types in PlanAction.
plan_resource_change
Nested message and enum types in PlanResourceChange.
prepare_provider_config
Nested message and enum types in PrepareProviderConfig.
provider_client
Generated client implementations.
provider_server
Generated server implementations.
provision_resource
Nested message and enum types in ProvisionResource.
provisioner_client
Generated client implementations.
provisioner_server
Generated server implementations.
read_data_source
Nested message and enum types in ReadDataSource.
read_resource
Nested message and enum types in ReadResource.
renew_ephemeral_resource
Nested message and enum types in RenewEphemeralResource.
resource_identity_schema
Nested message and enum types in ResourceIdentitySchema.
schema
Nested message and enum types in Schema.
stop
Nested message and enum types in Stop.
upgrade_resource_identity
Nested message and enum types in UpgradeResourceIdentity.
upgrade_resource_state
Nested message and enum types in UpgradeResourceState.
validate_action_config
Nested message and enum types in ValidateActionConfig.
validate_data_source_config
Nested message and enum types in ValidateDataSourceConfig.
validate_ephemeral_resource_config
Nested message and enum types in ValidateEphemeralResourceConfig.
validate_list_resource_config
Nested message and enum types in ValidateListResourceConfig.
validate_provisioner_config
Nested message and enum types in ValidateProvisionerConfig.
validate_resource_type_config
Nested message and enum types in ValidateResourceTypeConfig.

Structs

ActionSchema
ActionSchema defines the schema for an action that can be invoked by Terraform.
ApplyResourceChange
AttributePath
CallFunction
ClientCapabilities
ClientCapabilities allows Terraform to publish information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
CloseEphemeralResource
Configure
Deferred
Deferred is a message that indicates that change is deferred for a reason.
Diagnostic
DynamicValue
DynamicValue is an opaque encoding of terraform data, with the field name indicating the encoding scheme used.
Function
FunctionError
GenerateResourceConfig
GetFunctions
GetMetadata
GetProviderSchema
GetProvisionerSchema
GetResourceIdentitySchemas
ImportResourceState
InvokeAction
ListResource
MoveResourceState
OpenEphemeralResource
PlanAction
PlanResourceChange
PrepareProviderConfig
ProvisionResource
RawState
RawState holds the stored state for a resource to be upgraded by the provider. It can be in one of two formats, the current json encoded format in bytes, or the legacy flatmap format as a map of strings.
ReadDataSource
ReadResource
RenewEphemeralResource
ResourceIdentityData
ResourceIdentitySchema
ResourceIdentitySchema represents the structure and types of data used to identify a managed resource type. Effectively, resource identity is a versioned object that can be used to compare resources, whether already managed and/or being discovered.
Schema
Schema is the configuration schema for a Resource, Provider, or Provisioner.
ServerCapabilities
ServerCapabilities allows providers to communicate extra information regarding supported protocol features. This is used to indicate availability of certain forward-compatible changes which may be optional in a major protocol version, but cannot be tested for directly.
Stop
UpgradeResourceIdentity
UpgradeResourceState
ValidateActionConfig
ValidateDataSourceConfig
ValidateEphemeralResourceConfig
ValidateListResourceConfig
ValidateProvisionerConfig
ValidateResourceTypeConfig

Enums

StringKind