pub struct ResourceIdentitySchema {
pub version: i64,
pub identity_attributes: Vec<IdentityAttribute>,
}Expand description
ResourceIdentitySchema represents the structure and types of data used to identify a managed resource type. Effectively, resource identity is a versioned object that can be used to compare resources, whether already managed and/or being discovered.
Fields
version: i64version is the identity version and separate from the Schema version. Any time the structure or format of identity_attributes changes, this version should be incremented. Versioning implicitly starts at 0 and by convention should be incremented by 1 each change.
When comparing identity_attributes data, differing versions should always be treated as inequal.
identity_attributes: Vec<IdentityAttribute>identity_attributes are the individual value definitions which define identity data for a managed resource type. This information is used to decode DynamicValue of identity data.
These attributes are intended for permanent identity data and must be wholly representative of all data necessary to compare two managed resource instances with no other data. This generally should include account, endpoint, location, and automatically generated identifiers. For some resources, this may include configuration-based data, such as a required name which must be unique.